pygeodesy.triaxials.bases._Triaxial3Base

Package pygeodesy :: Package triaxials :: Module bases :: Class _Triaxial3Base |
[frames] | no frames]

# Class _Triaxial3Base

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
      _UnOrderedTriaxialBase --+
                               |
            _OrderedTriaxialBase --+
                                   |
                                  _Triaxial3Base

Known Subclasses:
  - conformal3.Conformal3
  - , triaxial3.Triaxial3
  - , triaxial5.TriaxialB

(INTERNAL) Base class for unordered triaxial`3` classes.

Instance Methods
Inherited from `_OrderedTriaxialBase`: `__init__` Inherited from `_UnOrderedTriaxialBase`: `__repr__`, `areaKT`, `area_p`, `ellipse5`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| Lon0 Class `property` with a `.name` attribute.
| e2 Get the squared eccentricity (`scalar`), (a**2 - c**2) / b**2.
| isBiaxial Is this triaxial biaxial (`bool`), `a` == `b` or `b` == `c`?
| isOblate Is this triaxial oblate (`bool`), `a` == `b`?
| isProlate Is this triaxial prolate (`bool`), `b` == `c`?
| k2 (INTERNAL) Get the oblate `k2` parameter squared.
| kp2 (INTERNAL) Get the prolate `kp2` parameter squared.
Inherited from `_OrderedTriaxialBase`: `area`, `area21k` Inherited from `_UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOrdered`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Property Details

### Lon0 Class `property` with a `.name` attribute. Get method: Lon0(self) Set method: Lon0(self, lon0)

### e2 Get the squared eccentricity (`scalar`), (a**2 - c**2) / b**2. Get method: e2(self) - Get the squared eccentricity (`scalar`), (a**2 - c**2) / b**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isBiaxial Is this triaxial biaxial (`bool`), `a` == `b` or `b` == `c`? Get method: isBiaxial(self) - Is this triaxial biaxial (`bool`), `a` == `b` or `b` == `c`? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isOblate Is this triaxial oblate (`bool`), `a` == `b`? Get method: isOblate(self) - Is this triaxial oblate (`bool`), `a` == `b`? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isProlate Is this triaxial prolate (`bool`), `b` == `c`? Get method: isProlate(self) - Is this triaxial prolate (`bool`), `b` == `c`? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### k2 (INTERNAL) Get the oblate `k2` parameter squared. Get method: k2(self) - (INTERNAL) Get the oblate `k2` parameter squared. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### kp2 (INTERNAL) Get the prolate `kp2` parameter squared. Get method: kp2(self) - (INTERNAL) Get the prolate `kp2` parameter squared. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.